PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all documented functions with links to the struct/union documentation for each field:

### - _ -

- _add() : Path

### - a -

- add() : Path
- addOccludedObject() : Component
- addPin() : Component
- adjustLayoutAreaMargins() : PCBoard
- appendTrack() : Connection
- arePinsOnNet() : Connection
- autocreateConnections() : Net

### - b -

- bbox() : Track

### - c -

- checkRasterization() : Connection
- compound() : Pin
- computeLength() : Path
- connectivity() : Component
- create() : StateRepresentation

### - d -

- draw1To1() : NavImage< chan_t >

### - e -

- equals() : Segment_25
- extendTo() : Path
- extract() : Net

### - f -

- forceConnectionsToGrid() : PCBoard
- forceRouted() : Connection
- fromPy() : WideSegment_25

### - g -

- gatherConnections() : Component
- getBoard() : Net
- getCenter25() : Object
- getDirection() : Segment_25
- getEndsPy() : Connection
- getExpansionForTracks() : NavSpacings
- getHalfWidthSpan() : WideSegment_25
- getLock() : PCBoard
- getPCB() : Agent
- getPy() : AShape, CircleEx, Connection, IsoRectEx, PolygonEx, TriangleEx, WideSegment_25
- getRatsNest() : Connection
- getStartLayerFor() : Pin
- getTracksPy() : Connection
- getUserAgent() : UIApplication
- grow() : PolygonEx
- grown() : WideSegment_25

### - h -

- hasViaExtent() : Net

### - i -

- initPathfindingForNet() : PCBoard
- intersects() : Connection
- isOrderedXMajor() : Connection
- isRasterized_allOrNone() : Connection

### - j -

- joins2D() : WideSegment_25

### - l -

- length() : Path
- lengthOutside() : IsoRectEx
- logAction() : StateRepresentation

### - m -

- makeDirectTrack45() : Connection

### - n -

- nudge() : WideSegment_25
- numNecessaryVias() : Connection

### - o -

- operator()() : ObjectPtrNameLessThan
- opposite() : WideSegment_25
- otherEnd() : Via

### - p -

- pruneConnections() : Net
- py_event() : Agent
- py_V() : Agent

### - r -

- rectify() : WideSegment_25
- removeAndDisconnectPin() : Component
- reverse() : Connection
- RMSD() : Path
- runPathFinding() : PCBoard

### - s -

- s2_extended() : WideSegment_25
- select() : ObjectsBVH
- setColor() : Connection
- setColorAuto() : Net
- setFocus() : StateRepresentation
- setId() : Net
- setLocation() : Component
- setNumLayers() : PCBoard
- setPoints() : Path
- setPolicy() : Agent
- setTrack() : Connection
- swapWL() : WideSegment_25

### - t -

- transform() : AShape, CircleEx, IsoRectEx, PolygonEx, TriangleEx, WideSegment_25
- transformPreservesType() : AShape, CircleEx, IsoRectEx
- transformType() : AShape, IsoRectEx

### - u -

- updateForRemovedLayers() : Connection

### - v -

- vertexCount() : AShape, CircleEx, IsoRectEx, PolygonEx, TriangleEx, WideSegment_25
- violatesClearance() : Track, WideSegment_25

### - w -

- winding() : Path
- worldPosToNormalizedPos() : Camera